==> netbeans_6.1.orig.tar.gz: netbeans-6.1/xml.schema.completion/src/org/netbeans/modules/xml/schema/completion/spi/CompletionContext.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 1997-2007 Sun Microsystems, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Sun in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * Contributor(s):
 *
 * The Original Software is NetBeans. The Initial Developer of the Original
 * Software is Sun Microsystems, Inc. Portions Copyright 1997-2007 Sun
 * Microsystems, Inc. All Rights Reserved.
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 */
package org.netbeans.modules.xml.schema.completion.spi;

import java.net.URI;
import java.util.HashMap;
import java.util.List;
import javax.xml.namespace.QName;
import org.netbeans.editor.BaseDocument;
import org.openide.filesystems.FileObject;

/**
 * Represents code completion context at the current cursor location.
 *
 * @author Samaresh (Samaresh@Netbeans.Org)
 */
public abstract class CompletionContext {
    
    /**
     * Returns the default namespace for the document.
     */
    public abstract String getDefaultNamespace();
    
    /**
     * Returns the type of completion.
     */
    public abstract CompletionType getCompletionType();
        
    /**
     * Returns the path from root element to the cursor location.
     */
    public abstract List<QName> getPathFromRoot();
    
    /**
     * Returns the FileObject for the document.
     */
    public abstract FileObject getPrimaryFile();
    
    /**
     * Returns the BaseDocument for the document.
     */
    public abstract BaseDocument getBaseDocument();
    
    /**
     * Returns all the namespaces declared in the document as a HashMap.
     */
    public abstract HashMap<String, String> getDeclaredNamespaces();
    
    /**
     * Returns the typed characters during completion.
     */
    public abstract String getTypedChars();
            
    /**
     * CompletionType.
     */
    public static enum CompletionType {
        COMPLETION_TYPE_UNKNOWN,
        COMPLETION_TYPE_ATTRIBUTE,
        COMPLETION_TYPE_VALUE,
        COMPLETION_TYPE_ELEMENT,
        COMPLETION_TYPE_ENTITY,
        COMPLETION_TYPE_NOTATION,
        COMPLETION_TYPE_DTD
    }
}

==> netbeans_6.7.1.orig.tar.gz: netbeans-6.7.1/xml.schema.completion/src/org/netbeans/modules/xml/schema/completion/spi/CompletionContext.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 1997-2007 Sun Microsystems, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Sun in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * Contributor(s):
 *
 * The Original Software is NetBeans. The Initial Developer of the Original
 * Software is Sun Microsystems, Inc. Portions Copyright 1997-2007 Sun
 * Microsystems, Inc. All Rights Reserved.
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 */
package org.netbeans.modules.xml.schema.completion.spi;

import java.net.URI;
import java.util.HashMap;
import java.util.List;
import javax.xml.namespace.QName;
import org.netbeans.editor.BaseDocument;
import org.openide.filesystems.FileObject;

/**
 * Represents code completion context at the current cursor location.
 *
 * @author Samaresh (Samaresh@Netbeans.Org)
 */
public abstract class CompletionContext {
    
    /**
     * Returns the default namespace for the document.
     */
    public abstract String getDefaultNamespace();
    
    /**
     * Returns the type of completion.
     */
    public abstract CompletionType getCompletionType();
        
    /**
     * Returns the path from root element to the cursor location.
     */
    public abstract List<QName> getPathFromRoot();
    
    /**
     * Returns the FileObject for the document.
     */
    public abstract FileObject getPrimaryFile();
    
    /**
     * Returns the BaseDocument for the document.
     */
    public abstract BaseDocument getBaseDocument();
    
    /**
     * Returns all the namespaces declared in the document as a HashMap.
     */
    public abstract HashMap<String, String> getDeclaredNamespaces();
    
    /**
     * Returns the typed characters during completion.
     */
    public abstract String getTypedChars();
            
    /**
     * CompletionType.
     */
    public static enum CompletionType {
        COMPLETION_TYPE_UNKNOWN,
        COMPLETION_TYPE_ATTRIBUTE,
        COMPLETION_TYPE_ATTRIBUTE_VALUE,
        COMPLETION_TYPE_ELEMENT,
        COMPLETION_TYPE_ELEMENT_VALUE,
        COMPLETION_TYPE_ENTITY,
        COMPLETION_TYPE_NOTATION,
        COMPLETION_TYPE_DTD
    }
}
